# flake8: noqa

# import apis into api package
from public_api_server_connector.api.api_key_auth_api import ApiKeyAuthApi
from public_api_server_connector.api.api_keys_api import ApiKeysApi
from public_api_server_connector.api.api_logs_api import ApiLogsApi
from public_api_server_connector.api.api_spec_api import ApiSpecApi
from public_api_server_connector.api.courses_api import CoursesApi
from public_api_server_connector.api.general_api import GeneralApi
from public_api_server_connector.api.health_api import HealthApi
from public_api_server_connector.api.jwt_token_auth_api import JwtTokenAuthApi
from public_api_server_connector.api.mediastorage_api import MediastorageApi
from public_api_server_connector.api.orders_api import OrdersApi
from public_api_server_connector.api.specification_api import SpecificationApi
from public_api_server_connector.api.v1_api import V1Api




# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from public_api_server_connector.models.ipn_order_payment_response import IpnOrderPaymentResponse

class ResponseWrapperIpnOrderPaymentResponse(BaseModel):
    """
    ResponseWrapperIpnOrderPaymentResponse
    """
    done: StrictBool = Field(default=..., description="Indicates if the operation was successful. True if successful, False otherwise. Always matches the HTTP status code. 2xx for success, 4xx or 5xx for failure.")
    result: Optional[IpnOrderPaymentResponse] = Field(default=None, description="The result of the operation, if successful. Should be an instance of the specified model. If the operation failed, this will always be null.")
    error: Optional[StrictStr] = Field(default=None, description="Error message if the operation failed. Should be a string describing the error. If the operation was successful, this will always be null.")
    __properties = ["done", "result", "error"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResponseWrapperIpnOrderPaymentResponse:
        """Create an instance of ResponseWrapperIpnOrderPaymentResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of result
        if self.result:
            _dict['result'] = self.result.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResponseWrapperIpnOrderPaymentResponse:
        """Create an instance of ResponseWrapperIpnOrderPaymentResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ResponseWrapperIpnOrderPaymentResponse.parse_obj(obj)

        _obj = ResponseWrapperIpnOrderPaymentResponse.parse_obj({
            "done": obj.get("done"),
            "result": IpnOrderPaymentResponse.from_dict(obj.get("result")) if obj.get("result") is not None else None,
            "error": obj.get("error")
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field
from public_api_server_connector.models.api_key_get import ApiKeyGet
from public_api_server_connector.models.portal_info import PortalInfo
from public_api_server_connector.models.portal_member_base import PortalMemberBase

class TokenInfo(BaseModel):
    """
    TokenInfo
    """
    api_key: ApiKeyGet = Field(...)
    portal: PortalInfo = Field(...)
    owner: PortalMemberBase = Field(...)
    __properties = ["api_key", "portal", "owner"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TokenInfo:
        """Create an instance of TokenInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of api_key
        if self.api_key:
            _dict['api_key'] = self.api_key.to_dict()
        # override the default output from pydantic by calling `to_dict()` of portal
        if self.portal:
            _dict['portal'] = self.portal.to_dict()
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TokenInfo:
        """Create an instance of TokenInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TokenInfo.parse_obj(obj)

        _obj = TokenInfo.parse_obj({
            "api_key": ApiKeyGet.from_dict(obj.get("api_key")) if obj.get("api_key") is not None else None,
            "portal": PortalInfo.from_dict(obj.get("portal")) if obj.get("portal") is not None else None,
            "owner": PortalMemberBase.from_dict(obj.get("owner")) if obj.get("owner") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictInt, StrictStr
from public_api_server_connector.models.api_key_get import ApiKeyGet

class ApiKeyCreateResponse(BaseModel):
    """
    ApiKeyCreateResponse
    """
    id: StrictInt = Field(default=..., description="The unique identifier of the API key.")
    api_key: StrictStr = Field(default=..., description="The API key that was created.")
    api_key_entity: ApiKeyGet = Field(default=..., description="The details of the created API key.")
    __properties = ["id", "api_key", "api_key_entity"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ApiKeyCreateResponse:
        """Create an instance of ApiKeyCreateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of api_key_entity
        if self.api_key_entity:
            _dict['api_key_entity'] = self.api_key_entity.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ApiKeyCreateResponse:
        """Create an instance of ApiKeyCreateResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ApiKeyCreateResponse.parse_obj(obj)

        _obj = ApiKeyCreateResponse.parse_obj({
            "id": obj.get("id"),
            "api_key": obj.get("api_key"),
            "api_key_entity": ApiKeyGet.from_dict(obj.get("api_key_entity")) if obj.get("api_key_entity") is not None else None
        })
        return _obj


